<?php
/*
  Plugin Name: StopAdBlock
  Plugin URI:  http://stopadblock.org/
  Description: Displays a layer for users using adblock, showing how to deactivate it according to the users browser.
  Author: Boersensim.com / Soeren Ramspeck
  Version: 0.1
  Author URI: http://iopodx.de/
  License: GPLv2 or later
 */

class StopAdBlock {

    function __construct() {
        if (isset($_POST['saveCode'])) {
            update_option('sab_code', $_POST['saveCode']);
            update_option('sab_text', $_POST['sabText']);
            update_option('sab_method', $_POST['sabAction']);
            update_option('sab_delay', $_POST['sabDelay']);
            update_option('sab_div', $_POST['sabDiv']);
            update_option('sab_force', $_POST['sabForce']);
        }
        add_action('admin_menu', array($this, 'addMenu'));
        add_action('wp_head', array($this, 'printHead'));
        register_activation_hook('stopadblock/stopadblock.php', array($this, 'install'));
    }

    function install() {
        add_option('sab_method', 'blockpopup');
        add_option('sab_div', substr(md5(rand(0, 10000000)), 7, 5));
        add_option('sab_delay', 5);
        add_option('sab_force', FALSE);
        add_option('sab_text', "As you're currently using adblock, we highly encourage you to deactivate it to support this site.");
    }

    function addMenu() {
        add_menu_page('sab', __('StopAdBlock'), 'edit_posts', 'sab', array($this, 'menu'));
    }

    function printHead() {
        if (get_option('sab_code')) {
            echo get_option('sab_code');
        }
    }

    function menu() {
        ?>
        <h2><?php echo __('StopAdBlock Configuration'); ?></h2>
        <script type="text/javascript">
            jQuery(function() {
                jQuery('#downloadform').submit(function() {
                    if (jQuery('#blockpopup').attr('checked')) {
                        method = 'blockpopup';
                    } else {
                        method = 'block';
                    }
                    jQuery.ajax({
                        url: 'http://www.stopadblock.org/ajax_download.php',
                        dataType: 'jsonp',
                        jsonp: 'jsonp_callback',
                        data: {
                            div: jQuery('#div').val(),
                            action: method,
                            force: jQuery('#force').val(),
                            timeout: jQuery('#delay').val(),
                            notice: jQuery('#notice').val()

                        },
                        success: function(data) {
                            jQuery.ajax({
                                url: location.href,
                                type: 'POST',
                                data: {
                                    saveCode: data,
                                    sabText: jQuery('#notice').val(),
                                    sabDiv: jQuery('#div').val(),
                                    sabForce: jQuery('#force').val(),
                                    sabDelay: jQuery('#delay').val(),
                                    sabAction: method
                                },
                                success: function() {
                                    location.href = location.href + '&' + Math.random();
                                }
                            });
                        }
                    });
                    return false;
                });
            });
        </script>

        <form id="downloadform">
            <div id="download">
                <h2>Code erstellen</h2>
                <table border="0">
                    <tr>
                        <td><?php echo __('div id of the ad being checked'); ?></td>
                        <td>#<input type="text" id="div" name="div" value="<?php echo get_option('sab_div'); ?>"></td>
                    </tr>
                    <tr>
                        <td><?php echo __('check the existence of this div'); ?></td>
                        <td><input type="checkbox" <?php echo (get_option('sab_div')) ? 'checked="checked "' : '' ?>value="true" name="force" id="force"></td>
                    <tr>
                        <td><?php echo __('action when adblock is detected'); ?></td>
                        <td>
                            <input <?php echo (get_option('sab_method') == 'blockpopup') ? ' checked="checked"' : ''; ?> type="radio" id="blockpopup" name="action" value="blockpopup">
                            <label for="blockpopup"><?php echo __('block and show deactivation tutorial according to the users browser'); ?>(<strong>standard</strong>)</label> <br />
                            <input <?php echo (get_option('sab_method') == 'block') ? ' checked="checked"' : ''; ?> type="radio" id="block" name="action" value="block">
                            <label for="block"><?php echo __('don\'t show tutorial, but message'); ?></label><br />
                        </td>
                    </tr>
                    <tr>
                        <td><?php echo __('delay between two notifications'); ?></td>
                        <td><input type="text" id="delay" name="delay" value="<?php echo get_option('sab_delay'); ?>" /> <?php echo __('minutes'); ?></td>
                    </tr>
                    <tr>
                        <td><?php echo __('message shown to the user - HTML allowed!'); ?></td>
                        <td>
                            <textarea id="notice" name="notice" style="width:350px;height:250px"><?php echo get_option('sab_text'); ?></textarea>
                        </td>
                    </tr>
                    <tr>
                        <td></td>
                        <td><input type="submit" value="<?php echo __('save settings'); ?>"></td>
                    </tr>
                </table>
            </div>
            <?php echo get_option('sab_code'); ?>
            <?php
        }

    }

    new StopAdBlock;